==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1ScaleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface AppsV1beta1ScaleFluent<A extends AppsV1beta1ScaleFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> withNewMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public AppsV1beta1ScaleFluent.MetadataNested<A> editMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> editOrNewMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1ScaleSpec getSpec();
    public AppsV1beta1ScaleSpec buildSpec();
    public A withSpec(AppsV1beta1ScaleSpec spec);
    public Boolean hasSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> withNewSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> withNewSpecLike(AppsV1beta1ScaleSpec item);
    public AppsV1beta1ScaleFluent.SpecNested<A> editSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> editOrNewSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> editOrNewSpecLike(AppsV1beta1ScaleSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1ScaleStatus getStatus();
    public AppsV1beta1ScaleStatus buildStatus();
    public A withStatus(AppsV1beta1ScaleStatus status);
    public Boolean hasStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> withNewStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> withNewStatusLike(AppsV1beta1ScaleStatus item);
    public AppsV1beta1ScaleFluent.StatusNested<A> editStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> editOrNewStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> editOrNewStatusLike(AppsV1beta1ScaleStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<AppsV1beta1ScaleFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1ScaleSpecFluent<AppsV1beta1ScaleFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1ScaleStatusFluent<AppsV1beta1ScaleFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1ScaleFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface AppsV1beta1ScaleFluent<A extends AppsV1beta1ScaleFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> withNewMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public AppsV1beta1ScaleFluent.MetadataNested<A> editMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> editOrNewMetadata();
    public AppsV1beta1ScaleFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1ScaleSpec getSpec();
    public AppsV1beta1ScaleSpec buildSpec();
    public A withSpec(AppsV1beta1ScaleSpec spec);
    public Boolean hasSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> withNewSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> withNewSpecLike(AppsV1beta1ScaleSpec item);
    public AppsV1beta1ScaleFluent.SpecNested<A> editSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> editOrNewSpec();
    public AppsV1beta1ScaleFluent.SpecNested<A> editOrNewSpecLike(AppsV1beta1ScaleSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1ScaleStatus getStatus();
    public AppsV1beta1ScaleStatus buildStatus();
    public A withStatus(AppsV1beta1ScaleStatus status);
    public Boolean hasStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> withNewStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> withNewStatusLike(AppsV1beta1ScaleStatus item);
    public AppsV1beta1ScaleFluent.StatusNested<A> editStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> editOrNewStatus();
    public AppsV1beta1ScaleFluent.StatusNested<A> editOrNewStatusLike(AppsV1beta1ScaleStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<AppsV1beta1ScaleFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1ScaleSpecFluent<AppsV1beta1ScaleFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1ScaleStatusFluent<AppsV1beta1ScaleFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
